# shubham_test_library/core.py
def main_function(data):
    """Main function of the library."""
    return process_data(data)

def process_data(data):
    """Process the input data."""
    # Your implementation here
    return data * 2